@@ -1,6 +1,6 @@
 package App::JobLog::Command::configure;
 {
-  $App::JobLog::Command::configure::VERSION = '1.021';
+  $App::JobLog::Command::configure::VERSION = '1.022';
 }
 
 # ABSTRACT: examine or modify App::JobLog configuration
@@ -69,10 +69,10 @@ sub execute {
     }
     if ( defined $opt->sunday_begins_week ) {
         my $bool;
-        given ( $opt->sunday_begins_week ) {
+        for ( $opt->sunday_begins_week ) {
             when (/true/i)  { $bool = 1 }
             when (/false/i) { $bool = 0 }
-            default { $bool = $opt->sunday_begins_week || 0 }
+            default { $bool = $opt->sunday_begins_week || 0 };
         }
         $bool = sunday_begins_week($bool);
         say "Sunday begins week is now " . ( $bool ? 'true' : 'false' );
@@ -132,13 +132,16 @@ sub options {
         ],
         [
             'length-pay-period=i',
-            'the length of the pay period in days; e.g., --length-pay-period 7; '
+'the length of the pay period in days; e.g., --length-pay-period 7; '
               . 'default is '
               . PERIOD
         ],
         [
             'day-length=f',
-            'length of workday; ' . 'e.g., --day-length 7.5; ' . 'default is: ' . HOURS
+            'length of workday; '
+              . 'e.g., --day-length 7.5; '
+              . 'default is: '
+              . HOURS
         ],
         [
             'workdays=s',
@@ -271,7 +274,7 @@ App::JobLog::Command::configure - examine or modify App::JobLog configuration
 
 =head1 VERSION
 
-version 1.021
+version 1.022
 
 =head1 SYNOPSIS
 
