@@ -1,6 +1,6 @@
 package App::JobLog::Command::truncate;
 {
-  $App::JobLog::Command::truncate::VERSION = '1.021';
+  $App::JobLog::Command::truncate::VERSION = '1.022';
 }
 
 # ABSTRACT: decapitate the log
@@ -37,7 +37,7 @@ sub execute {
       $opt->compression ? _pick_compression( $opt->compression ) : 'IO::File';
     my $suffix = '';
     my @args   = ();
-    given ($io) {
+    for ($io) {
         when ('IO::File') { push @args, 'w' }
         when ('IO::Compress::Zip') {
             $suffix = '.zip';
@@ -46,7 +46,7 @@ sub execute {
         when ('IO::Compress::Gzip')  { $suffix = '.gz' }
         when ('IO::Compress::Bzip2') { $suffix = '.bz2' }
         when ('IO::Compress::Lzma')  { $suffix = '.lzma' }
-        default { die "unprepared to handle $io; please report bug" }
+        default { die "unprepared to handle $io; please report bug" };
     }
     my $old_f = File::Spec->catfile( dir, $base . $suffix );
     my $old_fh     = $io->new( $old_f, @args );
@@ -159,7 +159,7 @@ END
 # converts chosen compression opt into appropriate IO:: algorithm
 sub _pick_compression {
     my $alg = shift;
-    given ($alg) {
+    for ($alg) {
         when ('zip')   { return 'IO::Compress::Zip' }
         when ('gzip')  { return 'IO::Compress::Gzip' }
         when ('bzip2') { return 'IO::Compress::Bzip2' }
@@ -179,7 +179,7 @@ App::JobLog::Command::truncate - decapitate the log
 
 =head1 VERSION
 
-version 1.021
+version 1.022
 
 =head1 SYNOPSIS
 
